==> jc-1.4.0.tar.gz: java/util/logging/Formatter.h <==
// public abstract class java.util.logging.Formatter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class afd6918748171c7a java_util_logging_Formatter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_logging_Formatter_H_
#define _JC_java_util_logging_Formatter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_Handler$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_Formatter$sub_refs	_jc_java_util_logging_Formatter$sub_refs;
typedef struct _jc_java_util_logging_Formatter$sub_nonrefs	_jc_java_util_logging_Formatter$sub_nonrefs;
typedef struct _jc_java_util_logging_Formatter$refs	_jc_java_util_logging_Formatter$refs;
typedef struct _jc_java_util_logging_Formatter$nonrefs	_jc_java_util_logging_Formatter$nonrefs;
typedef struct _jc_java_util_logging_Formatter$object	_jc_java_util_logging_Formatter$object;

typedef const struct _jc_java_util_logging_Formatter$vmethods	_jc_java_util_logging_Formatter$vmethods;
typedef const struct _jc_java_util_logging_Formatter$vtable	_jc_java_util_logging_Formatter$vtable;
typedef const struct _jc_java_util_logging_Formatter$vtype	_jc_java_util_logging_Formatter$vtype;

// Constructors
extern void _jc_java_util_logging_Formatter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_Formatter$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$format$8b25c74979926e38(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$formatMessage$665fd04fb2de68c2(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$getHead$98b66758a6126109(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$getTail$ec946c1f995c0254(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_Formatter$method_info$format$8b25c74979926e38;
extern _jc_method _jc_java_util_logging_Formatter$method_info$formatMessage$665fd04fb2de68c2;
extern _jc_method _jc_java_util_logging_Formatter$method_info$getHead$98b66758a6126109;
extern _jc_method _jc_java_util_logging_Formatter$method_info$getTail$ec946c1f995c0254;

// Virtual methods structure
struct _jc_java_util_logging_Formatter$vmethods {
	struct _jc_java_lang_String$object	*(*format$8b25c74979926e38)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *);
	struct _jc_java_lang_String$object	*(*formatMessage$665fd04fb2de68c2)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *);
	struct _jc_java_lang_String$object	*(*getHead$98b66758a6126109)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *);
	struct _jc_java_lang_String$object	*(*getTail$ec946c1f995c0254)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *);
};

// Vtable
struct _jc_java_util_logging_Formatter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Formatter$vmethods	java_util_logging_Formatter;
};

// Vtype
struct _jc_java_util_logging_Formatter$vtype {
	_jc_type			type;
	_jc_java_util_logging_Formatter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_Formatter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_Formatter$refs {
    _jc_java_util_logging_Formatter$sub_refs	java_util_logging_Formatter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_Formatter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_Formatter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Formatter$sub_nonrefs	java_util_logging_Formatter;
};

// Object instance structure
struct _jc_java_util_logging_Formatter$object {
	_jc_java_util_logging_Formatter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_Formatter$vtype	*vtype;
	_jc_java_util_logging_Formatter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_Formatter$vtype _jc_java_util_logging_Formatter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_Formatter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_Formatter$class_object;

#endif	/* _JC_java_util_logging_Formatter_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/Formatter.h <==
// public abstract class java.util.logging.Formatter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class afd6918748171c7a java_util_logging_Formatter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_logging_Formatter_H_
#define _JC_java_util_logging_Formatter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_Handler$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_Formatter$sub_refs	_jc_java_util_logging_Formatter$sub_refs;
typedef struct _jc_java_util_logging_Formatter$sub_nonrefs	_jc_java_util_logging_Formatter$sub_nonrefs;
typedef struct _jc_java_util_logging_Formatter$refs	_jc_java_util_logging_Formatter$refs;
typedef struct _jc_java_util_logging_Formatter$nonrefs	_jc_java_util_logging_Formatter$nonrefs;
typedef struct _jc_java_util_logging_Formatter$object	_jc_java_util_logging_Formatter$object;

typedef const struct _jc_java_util_logging_Formatter$vmethods	_jc_java_util_logging_Formatter$vmethods;
typedef const struct _jc_java_util_logging_Formatter$vtable	_jc_java_util_logging_Formatter$vtable;
typedef const struct _jc_java_util_logging_Formatter$vtype	_jc_java_util_logging_Formatter$vtype;

// Constructors
extern void _jc_java_util_logging_Formatter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_Formatter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$format$8b25c74979926e38(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$formatMessage$665fd04fb2de68c2(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$getHead$98b66758a6126109(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_logging_Formatter$method$getTail$ec946c1f995c0254(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_Formatter$method_info$format$8b25c74979926e38;
extern _jc_method _jc_java_util_logging_Formatter$method_info$formatMessage$665fd04fb2de68c2;
extern _jc_method _jc_java_util_logging_Formatter$method_info$getHead$98b66758a6126109;
extern _jc_method _jc_java_util_logging_Formatter$method_info$getTail$ec946c1f995c0254;

// Virtual methods structure
struct _jc_java_util_logging_Formatter$vmethods {
	struct _jc_java_lang_String$object	*(*format$8b25c74979926e38)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*formatMessage$665fd04fb2de68c2)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getHead$98b66758a6126109)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTail$ec946c1f995c0254)(_jc_env *, struct _jc_java_util_logging_Formatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_Formatter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Formatter$vmethods	java_util_logging_Formatter;
};

// Vtype
struct _jc_java_util_logging_Formatter$vtype {
	_jc_type			type;
	_jc_java_util_logging_Formatter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_Formatter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_Formatter$refs {
    _jc_java_util_logging_Formatter$sub_refs	java_util_logging_Formatter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_Formatter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_Formatter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Formatter$sub_nonrefs	java_util_logging_Formatter;
};

// Object instance structure
struct _jc_java_util_logging_Formatter$object {
	_jc_java_util_logging_Formatter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_Formatter$vtype	*vtype;
	_jc_java_util_logging_Formatter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_Formatter$vtype _jc_java_util_logging_Formatter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_Formatter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_Formatter$class_object;

#endif	/* _JC_java_util_logging_Formatter_H_ */
